//
// MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software,
// and any derivatives created by any person or entity by or on your
// behalf, exclusively with Microchip’s products. Microchip and its
// licensors retain all ownership and intellectual property rights in
// the accompanying software and in all derivatives hereto.
//
// This software and any accompanying information is for suggestion
// only. It does not modify Microchip’s standard warranty for its
// products. You agree that you are solely responsible for testing the
// software and determining its suitability. Microchip has no obligation
// to modify, test, certify, or support the software.
//
// THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES,
// WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO,
// IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS
// FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
// MICROCHIP’S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN
// ANY APPLICATION.
//
// IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
// TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
// LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
// SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS,
// DAMAGE, FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE
// SOFTWARE, HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE
// // POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT
// ALLOWABLE BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY
// WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF
// ANY, THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
//
// MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE
// OF THESE TERMS.
//

/**
 * @file ST7032_cmds.h
 * @brief This file contains the defines applicable to using the ST7032 controller.
 * @ingroup slave
 * @{
 */

//******************************************************/
//		ST7032_cmds Defines
//******************************************************/
// Command set for the St7032 LCD driver used by the Newhaven NHD-C0216CZ-FSW-FBW

#ifndef __ST7032_CMDS_H
#define __ST7032_CMDS_H


#define ST7032_CLEAR                0x01
#define ST7032_HOME                 0x02

#define CURSOR_nSHIFT               0x00
#define CURSOR_SHIFT                0x01
#define DATA_DECREMENT              0x00
#define DATA_INCREMENT              0x02
#define ST7032_ENTRY_MODE           0x04

#define CURSOR_OFF                  0x00
#define CURSOR_ON                   0x02
#define BLINK_OFF                   0x00
#define BLINK_ON                    0x01
#define ST7032_DISPLAY_OFF          0x08
#define ST7032_DISPLAY_ON           0x0C


#define FUNCTION_nIS                0x00
#define FUNCTION_IS                 0x01
#define FUNCTION_1_HIGH             0x00
#define FUNCTION_2_HIGH             0x04
#define FUNCTION_1_LINE             0x00
#define FUNCTION_2_LINE             0x08
#define FUNCTION_4BITS              0x00
#define FUNCTION_8BITS              0x10

#define ST7032_FUNCTION 0x20

#define ST7032_CGRAM_ADDRESS(adr)   (0x40 | (adr & 0x3F))
#define ST7032_DDRAM_ADDRESS(adr)   (0x80 | (adr & 0x7F))

//** Second Instruction Page (IS)
#define BIAS_1_5                    0x00
#define BIAS_1_4                    0x08
#define FREQ_CNTRL(f)               (f&0x07)
#define ST7032_OSC_FREQ             0x10


#define ST7032_ICON_ADDRESS(adr)    (0x40 | (adr & 0x0F))

#define nICON                       0x00
#define ICON                        0x08
#define nBOOST                      0x00
#define BOOST                       0x04
#define CONTRAST(c)                 (c&0x03)
#define ST7032_PWR_CONTROL          0x50

#define FOLLOWER_GAIN(g)            (g&0x07)
#define ST7032_FOLLOWER_OFF         0x60
#define ST7032_FOLLOWER_ON          0x68

#define ST7032_CONTRAST(c)          (0x70 | (c & 0x0F))

#define ST7032_BUSY_FLAG_MASK       0x80
#define ST7032_ADDRESS_MASK         0x7F

#define ST7032_ADDRESS_LINE_1       0x00
#define ST7032_ADDRESS_LINE_2       0x40

#endif //__ST7032_CMDS_H

/** @}*/