/***********************************************************************
 * MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software, and
 * any derivatives created by any person or entity by or on your behalf,
 * exclusively with Microchip's products. Microchip and its licensors
 * retain all ownership and intellectual property rights in the
 * accompanying software and in all derivatives hereto.
 *
 * This software and any accompanying information is for suggestion only.
 * It does not modify Microchip's standard warranty for its products. You
 * agree that you are solely responsible for testing the software and
 * determining its suitability. Microchip has no obligation to modify,
 * test, certify, or support the software.
 *
 * THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
 * EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED
 * WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
 * MICROCHIP'S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY
 * APPLICATION.
 *
 * IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
 * TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
 * LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
 * SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE,
 * FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE SOFTWARE,
 * HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE POSSIBILITY
 * OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT ALLOWABLE BY LAW,
 * MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO THIS
 * SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY, THAT YOU HAVE PAID
 * DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
 *
 * MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF
 * THESE TERMS.
 *************************************************************************/
 /****************************************************************************
 * Revision History
 * Date		Rev	 Author  Comments
 * 09.20.10 1.00         Public Release
 ****************************************************************************/
/** @file m_i2c.h
* @brief Header file for I2C communication procedures
*/

#include "lcd_target.h"
#include "main.h"
#include <htc.h>
#include "pic16f1509.h"
//#include "bodycom_config.h"


//*******************************************************************
//		I2C interface
//*******************************************************************
#define LCD_USE_MSSP1

#if defined(LCD_USE_MSSP1)

	#define MSSPSTAT		SSP1STAT
	#define MSSPSTATbits	SSP1STATbits
	#define MSSPADD			SSP1ADD 
	#define MSSPCON1		SSPCON1 
	#define MSSPCON2		SSP1CON2 
	#define MSSPCON2bits	SSP1CON2bits
	#define MSSPBUF			SSP1BUF

#elif defined(LCD_USE_MSSP2)

	#define MSSPSTAT		SSP2STAT
	#define MSSPSTATbits	SSP2STATbits
	#define MSSPADD			SSP2ADD 
	#define MSSPCON1		SSP2CON1 
	#define MSSPCON2		SSP2CON2 
	#define MSSPCON2bits	SSP2CON2bits
	#define MSSPBUF			SSP2BUF

#else

    #error No MSSP module selected for LCD interfacing

#endif

//#define  SCL      	SSP_I2C_CLK			   		///< The SCL output pin
//#define  SCL_TRIS 	DIR_SSP_I2C_CLK  		 	///< The SCL Direction Register Bit
//#define  SDA		SSP_I2C_SDA					///< The SDA output pin
//#define  SDA_TRIS 	DIR_SSP_I2C_SDA    			///< The SDA Direction Register Bit

#define  SCL      	LATB6			   		///< The SCL output pin
#define  SCL_TRIS 	TRISB6  		 	///< The SCL Direction Register Bit
#define  SDA		LATB4					///< The SDA output pin
#define  SDA_TRIS 	TRISB4    			///< The SDA Direction Register Bit

#define RST_TRIS        TRISC0
#define RST             LATC0

//#define ANSEL_I2C_SDA   ANSB6
#define ANSEL_I2C_CLK   ANSB4

#define I2CLOW  0         ///< Puts pin into output/low mode
#define I2CHIGH 1         ///< Puts pin into Input/high mode


//********************* FUNCTIONS ************************
void I2CReadBuffer(char Cmd, char Index, char Size,  char *Data);
unsigned char I2C_Send(unsigned char *Data, unsigned char Num, unsigned char offset);
char I2C_Read(char *Data,char Num);

void i2c_init(void);
void i2c_sendbyte(unsigned char data);
//char i2c_sendbyte(char byte);
char i2c_getbyte(void);
char i2c_getack(void);
void i2c_sendack(void);
void i2c_start(void);
void i2c_stop(void);


void i2cclock(void);
char i2creadbit(void);

