/********************************************************************
 *
 *
 *
 *********************************************************************
 * FileName:         manchester.c
 * Dependencies:     See INCLUDES section below
 * Processor:        PIC16F509
 * Compiler:         XC8
 * Company:          Microchip Technology, Inc.
 *
 * Software License Agreement:
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") for its PICmicro® Microcontroller is intended and
 * supplied to you, the Company's customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *********************************************************************
 * File Description: This file contains functions for the Manchester Decoder
 *
 * Change History:
 * Author               Date        Version
 * Brian Bailey        6-8-12         1.0A  (Initial Release)
 ********************************************************************/

#include "../include/include.h"

unsigned char command = 0;
unsigned int byte = 0;
int transmit_flag = 0;
unsigned char message[17];
unsigned int LCD_Line;

void decoder_init(void)
{
//***********************************************
    /***************************************************************/
    //Setup CLC
    /***************************************************************/

//#include "lab2.inc"
//#include "CLC Decoder.inc"
    //Setup Manchester Decoder Step 1

    CLC4GLS0 = 0x02;
    CLC4GLS1 = 0x80;
    CLC4GLS2 = 0x00;
    CLC4GLS3 = 0x00;
    CLC4SEL0 = 0x61;
    CLC4SEL1 = 0x44;
    CLC4POL = 0x81;
    CLC4CON = 0xC4;

    //Setup Manchester Decoder Step 2

    CLC2GLS0 = 0x04;
    CLC2GLS1 = 0x00;
    CLC2GLS2 = 0x02;
    CLC2GLS3 = 0x00;
    CLC2SEL0 = 0x70;
    CLC2SEL1 = 0x02;
    CLC2POL = 0x00;
    CLC2CON = 0xC1;

    //Setup Manchester Decoder Step 3

    CLC1GLS0 = 0x08;
    CLC1GLS1 = 0x20;
    CLC1GLS2 = 0x20;
    CLC1GLS3 = 0x80;
    CLC1SEL0 = 0x51;
    CLC1SEL1 = 0x05;
    CLC1POL = 0x00;
    CLC1CON = 0x80;

    /***************************************************************/


    /***************************************************************/
    //Setup NCO
    /***************************************************************/

    // Fill increment Register, Pulse Frequency mode, 4 Clocks
    // Remember, write to the HIGH register first, and then the LOW register
    // Values are latched after write to the LOW increment register

    // Setup the NCO to overflow every 3/4 of the input pulse
    // Pulse @25KHz = 40us

    // 1 / (3/4 * 40us) = 33.33KHz
    // NCOFoverflow = (NCOclk * Incr) / (2^n)  -> where 'n' = 20 bits
    // Incr = (33.33KHz * (2^20) / 16MHz) = xxx

    NCO1INCH = 0x08;
    NCO1INCL = 0x88;

    // Setup pulse width to be 1 clock

    NCO1CLKbits.N1PWS1 = 1; //Pulse width is 4 clocks
    NCO1CLKbits.N1CKS1 = 1; //Clock source is CLC1 out.
    NCO1CON = 0b11010001; //NCO Enabled, Output Enabled, Signal is Active Low (datasheet is wrong)
    //Configured for Pulse Frequency Mode

//***********************************************
}

void decode_data(unsigned char data)
{
     
    //First Byte
    spi_init(Master);

    switch(data){           //First byte
        case 0xA1:          //LCD Write, Line 1
            command = 1;
            byte = 0;
            LCD_Line = 0;
            break;
        case 0xA2:          //LCD Write, Line 2
            command = 1;
            byte = 0;
            LCD_Line = 1;
            break;
        case 0xA5:          //Motor Speed
            command = 2;
            byte = 0;
            break;
        case 0xAA:          //Stop Command
            command = 0;
            transmit_flag = 0;  //transmition finished
            message[byte] = 0;  //null
            break;
        default:{
        //Remaining bytes
            switch(command){
                case 0:         //Error first byte not start byte
                    transmit_flag = 2;  //Error flag
                    break;

                case 1:         //LCD Write
                    message[byte] = data;
                    byte++;
                    break;

                case 2:         //Motor Speed

                    break;

                default:

                    break;

            }
            
        }
        break;
    }

    return;
}