
/**
 * @file uart.c
 * @defgroup uart UART
 * @{
 *
 */

#include <htc.h>
#include "bsp.h"
#include "uart.h"
#include <stdio.h> //printf
#include <string.h> //sprintf

/**
 * @brief Configures UART-1 module for 9600 baud
 * @note If this is changed, you must change it in the GUI as well
 */
void mcp2200_init(void)
{
    TRIS_UART_RX= 1;    //hardware UART module requires RX/TX to be inputs
    TRIS_UART_TX = 1;   //MUST be an input

    TXSTA = 0x00;
    RCSTA = 0x00;
    BAUDCON = 0x00;

    SPBRGL = DIVIDER;      //9600 baud
    TXSTAbits.BRGH = 0;    //Low speed
    BAUDCONbits.BRG16 = 0; //8-bit baud generator value
    BAUDCONbits.SCKP = 0;  //non-inverted
    TXSTAbits.SYNC = 0;    //asynchronous mode
    RCSTAbits.CREN = 1;    //enable RX
    TXSTAbits.TX9 = 0;     //8bit transmissions

    TXSTAbits.TXEN = 1;    //enable TX
    RCSTAbits.SPEN = 1;    //enable serial port 

    //PIE1bits.RCIE = 1;    //enable RX interrupts
}

/**
 * Outputs a message to prompt the user for a keypress through COM port
 */
void mcp2200_prompt(void) {
    char data_byte;
    char buffer[12];

    printf("\rPress a key and I will echo it back:\n");
    while (1) {
        data_byte = mcp2200_getch(); // read a response from the user
        printf("\rI detected [%c]", data_byte); // echo it back
        sprintf(buffer, "Number: %c", data_byte);
    }

}

/**
 * Prints a single character
 * If using PRINTF, this MUST be avaliable!
 *
 * @param byte unsigned char
 */
void putch_uart(UINT8 byte) {
    //First check to see if currently transmitting
    while (!TXIF) // will be set when register is empty
        continue; //wait until finished sending
    TXREG = byte; //now send the byte

}

/**
 * Receive one character from MCP2200
 * @return unsigned char RCREG
 */
char mcp2200_getch(void) {
    //First check to see if currently receiving
    while (!RCIF) // set when register is not empty
        continue; //wait until finished receiving the byte
    return RCREG; //we got the byte, lets return it
                  //if RCIE is enabled, RCIF will be set and an interrupt issued now
}

/**
 * A simple 'echo back what was sent'
 * @return unsigned char character sent
 */
char mcp2200_getche(void) {
    char c;

    putch(c = mcp2200_getch()); //wait until a byte is received and then echo it back
    return c;

}


/** @}*/