/**
 * @file bsp.h
 * @brief board specific definitions
 *
 * PIC16LF1947 board connections
 * <table>
 * <tr><th>Pin</th><th>Signal</th></tr>
 * <tr><td>RA0</td><td>NC</td></tr>
 * <tr><td>RA1</td><td>NC</td></tr>
 * <tr><td>RA2</td><td>NC</td></tr>
 * <tr><td>RA3</td><td>NC</td></tr>
 * <tr><td>RA4</td><td>NC</td></tr>
 * <tr><td>RA5</td><td>NC</td></tr>
 * <tr><td>RA6</td><td>NC</td></tr>
 * <tr><td>RA7</td><td>NC</td></tr>
 * <tr><td>RB0</td><td>Pushbutton</td></tr>
 * <tr><td>RB1</td><td>Pushbutton</td></tr>
 * <tr><td>RB2</td><td>PIC-to-PIC PGC</td></tr>
 * <tr><td>RB3</td><td>Pushbutton</td></tr>
 * <tr><td>RB4</td><td>Pushbutton</td></tr>
 * <tr><td>RB5</td><td>RTCC nIRQ</td></tr>
 * <tr><td>RB6</td><td>In-circuit debugging</td></tr>
 * <tr><td>RB7</td><td>In-circuit debugging</td></tr>
 * <tr><td>RC0/T1CKI</td><td>RTCC CLKOUT</td></tr>
 * <tr><td>RC1</td><td>NC</td></tr>
 * <tr><td>RC2</td><td>NC</td></tr>
 * <tr><td>RC3/SCK1</td><td>SPI bus SCK</td></tr>
 * <tr><td>RC4/SDI1</td><td>SPI bus MISO</td></tr>
 * <tr><td>RC5/SDO1</td><td>SPI bus MOSI</td></tr>
 * <tr><td>RC6/TX1</td><td>MCP2200 UART TX</td></tr>
 * <tr><td>RC7/RX1</td><td>MCP2200 UART RX</td></tr>
 * <tr><td>RD0</td><td>Test point</td></tr>
 * <tr><td>RD1</td><td>Test point</td></tr>
 * <tr><td>RD2</td><td>Test point</td></tr>
 * <tr><td>RD3</td><td>Test point</td></tr>
 * <tr><td>RD4</td><td>Test point</td></tr>
 * <tr><td>RD5</td><td>Test point</td></tr>
 * <tr><td>RD6</td><td>Test point</td></tr>
 * <tr><td>RD7</td><td>Test point</td></tr>
 * <tr><td>RF0</td><td>LCD RS</td></tr>
 * <tr><td>RF1</td><td>LCD nCS</td></tr>
 * <tr><td>RF2</td><td>LCD RST</td></tr>
 * <tr><td>RF3</td><td>RTCC nCS</td></tr>
 * <tr><td>RF4</td><td>PIC-to-PIC MCLR</td></tr>
 * <tr><td>RF5</td><td>PIC-to-PIC PGD</td></tr>
 * <tr><td>RF6</td><td>NC</td></tr>
 * <tr><td>RF7</td><td>NC</td></tr>
 * <tr><td>RG0</td><td>MCP2200 SSPND</td></tr>
 * <tr><td>RG1</td><td>MCP2200 USBCFG</td></tr>
 * <tr><td>RG2</td><td>MCP2200 nCTS</td></tr>
 * <tr><td>RG3</td><td>MCP2200 nRTS</td></tr>
 * <tr><td>RG4</td><td>NC</td></tr>
 * <tr><td>RG5/MCLR</td><td>In-circuit debugging</td></tr>
 * <tr><td>RE0</td><td>LED</td></tr>
 * <tr><td>RE1</td><td>LED</td></tr>
 * <tr><td>RE2</td><td>LED</td></tr>
 * <tr><td>RE3</td><td>LED</td></tr>
 * <tr><td>RE4</td><td>LED</td></tr>
 * <tr><td>RE5</td><td>LED</td></tr>
 * <tr><td>RE6</td><td>LED</td></tr>
 * <tr><td>RE7</td><td>LED</td></tr>
 * </table>
 * 
 * @ingroup slave
 * @{
 */
#ifndef __BSP_H
#define __BSP_H

/** Needed for HI-TECH macro of __delay_us and __delay_ms */
#define _XTAL_FREQ              16000000
//#define _XTAL_FREQ              32000

//UART
#define TRIS_UART_TX            TRISCbits.TRISC6
#define TRIS_UART_RX            TRISCbits.TRISC7

#define UART_TX                 LATCbits.LATC6
#define UART_RX                 LATCbits.LATC7

//Pushbuttons
#define SW2_IN                  PORTAbits.RA5
#define SW2_DIR                 TRISAbits.TRISA5
#define SW3_IN                  PORTCbits.RC2
#define SW3_DIR                 TRISCbits.TRISC2

// LCD port pins

#define LCD_CS_OUT              LATAbits.LATA0
#define LCD_CS_DIR              TRISAbits.TRISA0
//#define LCD_PWR               not implementated - always ON
//#define LCD_PWR_DIR           not implementated - always ON
//#define LCD_BKLIGHT_OUT         LATEbits.LATE7
//#define LCD_BKLIGHT_DIR         TRISEbits.TRISE7
#define LCD_SCL                 LATBbits.LATB6
#define LCD_SCL_DIR             TRISBbits.TRISB6
#define LCD_SDI                 LATCbits.LATC7
#define LCD_SDI_DIR             TRISCbits.TRISC7
/** Register Select Signal. Low for instruction; high for data */
#define LCD_RS                  LATAbits.LATA2
#define LCD_RS_DIR              TRISAbits.TRISA2
/** Active low Reset Signal */
#define LCD_RST                 LATAbits.LATA5
#define LCD_RST_DIR             TRISAbits.TRISA5

//MCP2200 USB
#define USB_RX_IN               PORTCbits.RC7
#define USB_RX_DIR              TRISCbits.TRISC7
#define USB_TX_IN               PORTCbits.RC6
#define USB_TX_DIR              TRISCbits.TRISC6

//SPI

#define SPI_SCK_OUT             PORTBbits.RB6
#define SPI_SCK                 PORTBbits.RB6
#define SPI_SCK_DIR             TRISBbits.TRISB6
#define SPI_SDI_OUT             PORTBbits.RB4
#define SPI_SDI                 PORTBbits.RB4
#define SPI_SDI_DIR             TRISBbits.TRISB4
#define SPI_SDO_OUT             PORTCbits.RC7
#define SPI_SDO_DIR             TRISCbits.TRISC7

//LEDs
#define LED0_OUT                LATCbits.LATC4
#define LED0_DIR                TRISCbits.TRISC4
#define LED1_OUT                LATCbits.LATC5
#define LED1_DIR                TRISCbits.TRISC5
#define IRLED0_OUT              LATCbits.LATC4
#define IRLED0_DIR              TRISCbits.TRISC4
#define PHOTO_TRANS_IN          PORTBbits.RB5
#define PHOTO_TRANS_DIR         TRISBbits.TRISB5

#define LED2_OUT                LATAbits.LATA0
#define LED2_DIR                TRISAbits.TRISA0
#define LED3_OUT                LATCbits.LATC2
#define LED3_DIR                TRISCbits.TRISC2
#define LED_OFF                 0
#define LED_ON                  1

#endif
/** @}*/