/********************************************************************
 *
 *
 *
 *********************************************************************
 * FileName:         Main.c
 * Dependencies:     See INCLUDES section below
 * Processor:        PIC16F1829
 * Compiler:         HTC
 * Company:          Microchip Technology, Inc.
 *
 * Software License Agreement:
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") for its PICmicro® Microcontroller is intended and
 * supplied to you, the Company's customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *********************************************************************
 * File Description: This project is to create and demo working code with
 *                   the New Peripheral Demo Board. Spicifically the
 *                   the Manchester Decoder
 * Change History:
 * Author               Date        Version
 * Brian Bailey        7-9-12       1.0A  (Initial Release)
 ********************************************************************/

/**
 *   @file Main.c
 *   @brief
 *   @defgroup
 *
 */

//Manchester Decoder

#include "../include/include.h"
#include "../include/pic16_config.h"

volatile unsigned char data_in;


/********************************************************************
 * Function:             Interrupt Service Routine
 *
 * PreCondition: 	Interrupts must be enabled.
 *
 * Side Effects:
 */
/**
 * @ingroup  		ISR
 *
 * @brief    		This function is used for interrupts.
 *
 * @note    		None
 */

/*******************************************************************/
void interrupt isr(void) {

        if(IOCBFbits.IOCBF5){
            LED1_OUT = LED_ON;
            IOCBP5 = 0;
            IOCBN5 = 0;
            IOCBF5 = 0;
            transmit_flag = 1;  //start transmition
            data_in = spi_bb_read();
        }
}



static void main_init()
{
    OSCCON = 0x78;    //16MHz

    ANSELA = 0x01;
    ANSELB = 0x00;
    ANSELC = 0x00;

    TRISA = 0x00;
    TRISB = 0x00;
    TRISC = 0x00;

    PORTA = 0x00;
    PORTB = 0x00;
    PORTC = 0x00;

    LED1_DIR = 0;

    LED1_OUT = LED_OFF;

    PHOTO_TRANS_DIR = 1;

    // Manchester Decoder Pin Configurations
    TRISAbits.TRISA1 = 1; //CLC4 Decoder Clock Input
    TRISCbits.TRISC4 = 0; //CLC4 Decoder Data Out
    TRISBbits.TRISB5 = 1; //CLC4 Decoder Data Input
    TRISCbits.TRISC3 = 1; //CLC2 Decoder Data Input
    TRISAbits.TRISA2 = 0; //CLC1 Decoder Data Out
    TRISCbits.TRISC1 = 0; //NCO Out to SPI CLK and CLC
    
    buttons_init();
    __delay_ms(200);    //Wait for startup
    
    
}


/********************************************************************
 * Function:             Main
 *
 * PreCondition: 	None
 *
 * Side Effects: 	None
 */
/**
 * @ingroup  		Main
 *
 * @brief    		This is the main function
 *
 * @note    		None
 */

/*******************************************************************/
void main(void) {

    main_init();
    __delay_ms(200);    //Wait for startup
    
    spi_init(Master);       //Configure part for SPI Master for LCD
    lcd_init();

    Display_Splash();
    
    decoder_init();         //Configure Decoder (Lab 2)

    spi_init(Slave);        //Configure part for Manchester Receiving

    while (1) {

        asm("sleep");
        NOP();

        decode_data(data_in);
        
        if(transmit_flag == 1){
            //Data transmitting...
        }
        if(transmit_flag == 2){
            //Data Error - First byte not start byte
            spi_init(Master);

            lcd_clear();
            lcd_goto(0,0);
            printf("Error");
        }
        if(!transmit_flag){
            //Data finished
            LED1_OUT = LED_OFF;
            spi_init(Master);
            lcd_goto(0,LCD_Line);
            printf("%s", message);
        }

        spi_init(Slave);        //reinitialize interrupts
        LED1_OUT = LED_OFF;
    }
}

void Display_Splash(void)
{
    lcd_clear();
    lcd_goto(0,0);
    printf("Manchester");
    lcd_goto(0,1);
    printf("Decoder");
}


/********************************************************************
 * Function:             putch
 *
 * PreCondition: 	<stdio.h>
 *
 * Side Effects: 	None
 */
/**
 * @ingroup  		LCD
 *
 * @brief    		This function is used to enable printf()
 *
 * @note    		None
 */

/*******************************************************************/
void putch(char c)
{
    lcd_putchar(c);
}